@@ -706,7 +706,9 @@ def get_template(
                                 "install": {
                                     "runtime-versions": {"python": "3.7",},
                                     "commands": [
-                                        "pip install aws-service-catalog-puppet",
+                                        f"pip install {puppet_version}"
+                                        if "http" in puppet_version
+                                        else f"pip install aws-service-catalog-puppet=={puppet_version}",
                                     ],
                                 },
                                 "build": {
